Crate solana_entry

Crate solana_entry 

Modules

block_component
entry
The entry module is a fundamental building block of Proof of History. It contains a unique ID that is the hash of the Entry before it, plus the hash of the transactions within it. Entries cannot be reordered, and its field num_hashes represents an approximate amount of time since the last Entry was created.
entry_or_marker
Entry marker types for the PoH recording pipeline.
poh
The Poh module provides an object for generating a Proof of History.