pub enum BlockComponent {
EntryBatch(Vec<Entry>),
BlockMarker(VersionedBlockMarker),
}Variants
EntryBatch(Vec<Entry>)
BlockMarker(VersionedBlockMarker)
Implementations
Sourceimpl BlockComponent
impl BlockComponent
pub fn new_entry_batch(entries: Vec<Entry>) -> Result<Self, BlockComponentError>
pub const fn new_block_marker(marker: VersionedBlockMarker) -> Self
pub fn new_block_header(parent_slot: Slot, parent_block_id: Hash) -> Self
pub const fn as_marker(&self) -> Option<&VersionedBlockMarker>
pub fn infer_is_entry_batch(data: &[u8]) -> Option<bool>
pub fn infer_is_block_marker(data: &[u8]) -> Option<bool>
Sourcepub fn infer_is_empty_entry_batch(data: &[u8]) -> bool
pub fn infer_is_empty_entry_batch(data: &[u8]) -> bool
In Alpenglow an empty entry batch will fail to deserialize Leader’s should only use an empty entry batch to indicate that they are aborting the block