pub struct VotesAggregate { /* private fields */ }Implementations
Sourceimpl VotesAggregate
impl VotesAggregate
Sourcepub fn from_certificate(cert: &Certificate) -> Self
pub fn from_certificate(cert: &Certificate) -> Self
Creates a VotesAggregate from a Certificate’s signature and bitmap.
Panics
Panics if the signature cannot be converted to compressed format. This should never happen for valid certificates from the consensus pool.
Sourcepub fn uncompress_signature(&self) -> Result<BLSSignature, BlsError>
pub fn uncompress_signature(&self) -> Result<BLSSignature, BlsError>
Uncompresses the signature.
Sourcepub fn into_bitmap(self) -> Vec<u8> ⓘ
pub fn into_bitmap(self) -> Vec<u8> ⓘ
Consumes self and returns the bitmap.