Module entry

Module entry 

The entry module is a fundamental building block of Proof of History. It contains a unique ID that is the hash of the Entry before it, plus the hash of the transactions within it. Entries cannot be reordered, and its field num_hashes represents an approximate amount of time since the last Entry was created.

Structs

Entry
Each Entry contains three pieces of data. The num_hashes field is the number of hashes performed since the previous entry. The hash field is the result of hashing hash from the previous entry num_hashes times. The transactions field points to Transactions that took place shortly before hash was generated.
EntrySummary
EntryVerificationData
EntryVerificationState
UnverifiedSignatures
ValidatedHashedTransactions

Enums

EntryType
Typed entry to distinguish between transaction and tick entries

Constants

MAX_DATA_SHREDS_SIZE

Traits

EntrySlice

Functions

batch_verify
TODO: we will move this API into solana-sdk.
create_ticks
entries_to_verification_data
hash_signatures
hash_transactions
next_entry
Creates the next Tick or Transaction Entry num_hashes after start_hash.
next_entry_mut
next_hash
Creates the hash num_hashes after start_hash. If the transaction contains a signature, the final hash will be a hash of both the previous ID and the signature. If num_hashes is zero and there’s no transaction data, start_hash is returned.
next_versioned_entry
Creates the next Tick or Transaction Entry num_hashes after start_hash.
thread_pool_for_benches
thread_pool_for_tests
validate_and_hash_transactions
Validates and hashes the transactions included in the given entries.
verify_entries_cpu
verify_entries_cpu_in_pool

Type Aliases

EntryReceiver
EntrySender
MaxDataShredsLen