The entry module is a fundamental building block of Proof of History. It contains a
unique ID that is the hash of the Entry before it, plus the hash of the
transactions within it. Entries cannot be reordered, and its field num_hashes
represents an approximate amount of time since the last Entry was created.
Structs
- Entry
- Each Entry contains three pieces of data. The
num_hashesfield is the number of hashes performed since the previous entry. Thehashfield is the result of hashinghashfrom the previous entrynum_hashestimes. Thetransactionsfield points to Transactions that took place shortly beforehashwas generated. - Entry
Summary - Entry
Verification Data - Entry
Verification State - Unverified
Signatures - Validated
Hashed Transactions
Enums
- Entry
Type - Typed entry to distinguish between transaction and tick entries
Constants
Traits
Functions
- batch_
verify - TODO: we will move this API into solana-sdk.
- create_
ticks - entries_
to_ verification_ data - hash_
signatures - hash_
transactions - next_
entry - Creates the next Tick or Transaction Entry
num_hashesafterstart_hash. - next_
entry_ mut - next_
hash - Creates the hash
num_hashesafterstart_hash. If the transaction contains a signature, the final hash will be a hash of both the previous ID and the signature. If num_hashes is zero and there’s no transaction data, start_hash is returned. - next_
versioned_ entry - Creates the next Tick or Transaction Entry
num_hashesafterstart_hash. - thread_
pool_ for_ benches - thread_
pool_ for_ tests - validate_
and_ hash_ transactions - Validates and hashes the transactions included in the given entries.
- verify_
entries_ cpu - verify_
entries_ cpu_ in_ pool